==> nextcloud-app-mail-4.2.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/uz.js <==
OC.L10N.register(
    "mail",
    {
    "Personal" : "Personal",
    "Mail" : "Mail",
    "Save" : "Save",
    "Connect" : "Connect",
    "Name" : "Name",
    "Password" : "Password",
    "None" : "None",
    "Cancel" : "Cancel",
    "General" : "General",
    "List" : "Ro`yxat",
    "About" : "About",
    "Delete" : "Delete",
    "Search" : "Search",
    "Send" : "Send",
    "Refresh" : "Refresh",
    "From" : "Dan",
    "To" : "Gacha",
    "Choose" : "Choose",
    "Choose a file to add as attachment" : "Ilova sifatida qo'shish uchun faylni tanlang",
    "Choose a file to share as a link" : "Havola sifatida almashish uchun faylni tanlang",
    "_{count} attachment_::_{count} attachments_" : ["{count} qo'shimchalar"],
    "Confirm" : "Confirm",
    "Favorite" : "Favorite",
    "Back" : "Orqaga",
    "Create event" : "Tadbir yaratish",
    "All day" : "Butun kun",
    "Description" : "Tavsif",
    "Select" : "Select",
    "Accept" : "Qabul qiling",
    "Decline" : "Rad etish",
    "Remove" : "Remove",
    "email" : "email",
    "Other" : "Boshqa",
    "Move" : "Move",
    "Quota" : "kvota",
    "Saving" : "Saving",
    "Rename" : "Nomini o'zgartirish",
    "Subscribed" : "Obuna boʻlgan",
    "Reply" : "Javob bering",
    "Add" : "Add",
    "Close" : "Close",
    "Tags" : "Tags",
    "Untitled event" : "Nomsiz tadbir",
    "(organizer)" : "(tashkilotchi)",
    "Actions" : "Actions",
    "Port" : "Port",
    "All" : "All",
    "Favorites" : "Favorites",
    "Error while sharing file" : "Fayl almashishda xatolik yuz berdi"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-4.3.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/uz.js <==
OC.L10N.register(
    "mail",
    {
    "Personal" : "Personal",
    "Mail" : "Mail",
    "Save" : "Save",
    "Connect" : "Connect",
    "Name" : "Name",
    "Password" : "Password",
    "None" : "None",
    "Email address" : "E-pochta manzili",
    "Cancel" : "Cancel",
    "Accounts" : "Akkaunt",
    "General" : "General",
    "List" : "Ro`yxat",
    "About" : "About",
    "Delete" : "Delete",
    "Search" : "Search",
    "Send" : "Send",
    "Refresh" : "Refresh",
    "From" : "Dan",
    "To" : "Gacha",
    "Choose" : "Choose",
    "Choose a file to add as attachment" : "Ilova sifatida qo'shish uchun faylni tanlang",
    "Choose a file to share as a link" : "Havola sifatida almashish uchun faylni tanlang",
    "_{count} attachment_::_{count} attachments_" : ["{count} qo'shimchalar"],
    "Confirm" : "Confirm",
    "Favorite" : "Favorite",
    "More actions" : "Ko'proq harakatlar",
    "Back" : "Orqaga",
    "Create event" : "Tadbir yaratish",
    "All day" : "Butun kun",
    "Description" : "Tavsif",
    "Create" : "Yaratish",
    "Select" : "Select",
    "Accept" : "Qabul qiling",
    "Decline" : "Rad etish",
    "More options" : "Boshqa variantlar",
    "Remove" : "Remove",
    "email" : "email",
    "Other" : "Boshqa",
    "Translate" : "Tarjima",
    "Move" : "Move",
    "Quota" : "kvota",
    "Saving" : "Saving",
    "Rename" : "Nomini o'zgartirish",
    "Subscribed" : "Obuna boʻlgan",
    "Reply" : "Javob bering",
    "Add" : "Add",
    "Close" : "Close",
    "Date" : "Sana",
    "Tags" : "Tags",
    "Last 7 days" : "Oxirgi 7 kun",
    "Custom" : "Boshqa",
    "Not found" : "Topilmadi",
    "Untitled event" : "Nomsiz tadbir",
    "(organizer)" : "(tashkilotchi)",
    "Operator" : "Operator",
    "Actions" : "Actions",
    "Port" : "Port",
    "Account connected" : "Akkaunt ulangan",
    "All" : "All",
    "Favorites" : "Favorites",
    "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
    "Continue to %s" : " %sni davom eting"
},
"nplurals=1; plural=0;");
